import { Input, HostListener, EventEmitter } from '@angular/core';
var Tooltip = (function () {
    function Tooltip(viewContainerRef, elementRef, componentFactoryResolver, injector, positionService, renderer, rebirthUIConfig) {
        this.viewContainerRef = viewContainerRef;
        this.elementRef = elementRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.injector = injector;
        this.positionService = positionService;
        this.renderer = renderer;
        this.rebirthUIConfig = rebirthUIConfig;
        this.appendBody = false;
        this.trigger = 'hover';
        this.placement = 'top';
        this.triggers = {
            hover: ['mouseenter', 'mouseleave'],
            focus: ['focusin', 'focusout'],
            click: ['click'],
            manual: []
        };
        this.listens = [];
        this.positionChange = new EventEmitter();
    }
    Tooltip.prototype.ngOnInit = function () {
        var _this = this;
        var factory = this.componentFactoryResolver.resolveComponentFactory(this.tooltipPopupType);
        var viewContainerRef = this.appendBody ? this.rebirthUIConfig.rootContainer : this.viewContainerRef;
        // EXCEPTION: Expression has changed after it was checked when append to body;
        setTimeout(function () {
            _this.popupRef = viewContainerRef.createComponent(factory, 0, _this.injector);
            _this.fillPopup();
            _this.registerTriggers();
            _this.positionChange
                .filter(function () { return _this.popupRef && _this.popupRef.instance.isOpen; })
                .debounceTime(100)
                .distinctUntilChanged()
                .subscribe(function () { return _this.positionTooltip(); });
        });
        this.listens.push(this.renderer.listen('window', 'resize', function ($event) { return _this.positionChange.emit($event); }));
        if (this.appendBody) {
            this.listens.push(this.renderer.listen('window', 'scroll', function ($event) { return _this.positionChange.emit($event); }));
        }
    };
    Tooltip.prototype.onDocumentClick = function ($event) {
        if (this.trigger !== 'manual') {
            var hostElement = this.elementRef.nativeElement;
            if (!hostElement.contains($event.target)) {
                this.hide();
            }
        }
    };
    Tooltip.prototype.ngOnDestroy = function () {
        this.listens.forEach(function (unregister) { return unregister(); });
        this.removePopView();
    };
    Tooltip.prototype.removePopView = function () {
        if (this.popupRef) {
            this.popupRef.destroy();
        }
    };
    Tooltip.prototype.toggle = function () {
        if (this.popupRef.instance.isOpen) {
            return this.hide();
        }
        this.show();
    };
    Tooltip.prototype.show = function () {
        this.fillPopup();
        this.popupRef.instance.show();
        this.positionTooltip();
    };
    Tooltip.prototype.hide = function () {
        if (this.popupRef) {
            var popupComponent = this.popupRef.instance;
            popupComponent.hide();
        }
    };
    Tooltip.prototype.registerTriggers = function () {
        var _this = this;
        var hostElement = this.elementRef.nativeElement;
        var trigger = this.triggers[this.trigger];
        if (trigger[0]) {
            this.listens.push(this.renderer.listen(hostElement, trigger[0], function (event) {
                _this.show();
            }));
        }
        if (trigger[1]) {
            this.listens.push(this.renderer.listen(hostElement, trigger[1], function ($event) {
                _this.hide();
            }));
        }
    };
    Tooltip.prototype.positionTooltip = function () {
        var hostElement = this.elementRef.nativeElement;
        var targetElement = this.popupRef.location.nativeElement;
        var clientRect = this.positionService.positionElements(hostElement, targetElement, this.placement, this.appendBody);
        this.renderer.setStyle(targetElement, 'left', clientRect.left + "px");
        this.renderer.setStyle(targetElement, 'top', clientRect.top + "px");
    };
    Tooltip.prototype.fillPopup = function () {
        var popupComponent = this.popupRef.instance;
        popupComponent.content = this.getContent();
        popupComponent.cssClass = this.cssClass;
        popupComponent.context = this.context || {};
        popupComponent.placement = this.placement;
        return popupComponent;
    };
    return Tooltip;
}());
export { Tooltip };
Tooltip.propDecorators = {
    'context': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'appendBody': [{ type: Input },],
    'trigger': [{ type: Input },],
    'placement': [{ type: Input },],
    'onDocumentClick': [{ type: HostListener, args: ['document:click', ['$event'],] },],
};
//# sourceMappingURL=tooltip.js.map