import { Injectable } from '@angular/core';
var TreeViewService = (function () {
    function TreeViewService() {
    }
    TreeViewService.prototype.getSelectNodes = function (treeData) {
        return this.innerGetMatchedItems(null, treeData, function (node) { return node.$$select; });
    };
    TreeViewService.prototype.getCheckedNodes = function (treeData) {
        return this.innerGetMatchedItems(null, treeData, function (node) { return node.$$check; });
    };
    TreeViewService.prototype.getMatchedItems = function (treeData, match) {
        return this.innerGetMatchedItems(null, treeData, match);
    };
    TreeViewService.prototype.getFirstMatchedItem = function (treeData, match) {
        return this.innerGetFirstMatchedItem(null, treeData, match);
    };
    TreeViewService.prototype.getTreeNodeByValue = function (treeData, valueField, value) {
        return this.innerGetFirstMatchedItem(null, treeData, function (node) { return node[valueField] === value; });
    };
    TreeViewService.prototype.expendNodesByLevel = function (treeData, level) {
        var _this = this;
        if (!treeData || !level) {
            return;
        }
        treeData.forEach(function (nodeItem) {
            nodeItem.$$expend = true;
            _this.expendNodesByLevel(nodeItem.children, level - 1);
        });
    };
    TreeViewService.prototype.expendNodesByValue = function (treeData, valueField, value) {
        var paths = this.getNodePathByValue(treeData, valueField, value);
        if (paths) {
            paths.forEach(function (nodeItem) { return nodeItem.$$expend = true; });
        }
    };
    TreeViewService.prototype.getNodePathByValue = function (treeData, valueField, value) {
        if (!treeData) {
            return;
        }
        for (var i = 0; i < treeData.length; i++) {
            var nodeItem = treeData[i];
            if (nodeItem[valueField] === value) {
                return [nodeItem];
            }
            var matchNode = this.getNodePathByValue(nodeItem.children, valueField, value);
            if (matchNode && matchNode.length) {
                return [nodeItem].concat(matchNode);
            }
        }
    };
    TreeViewService.prototype.expendAllNodes = function (treeData) {
        this.innerLookNode(null, treeData, function (node) {
            node.$$expend = true;
        });
    };
    TreeViewService.prototype.collapseAllNodes = function (treeData) {
        this.innerLookNode(null, treeData, function (node) {
            node.$$expend = false;
        });
    };
    TreeViewService.prototype.checkAllNodes = function (treeData) {
        this.innerLookNode(null, treeData, function (node) {
            node.$$check = true;
        });
    };
    TreeViewService.prototype.unCheckAllNodes = function (treeData) {
        this.innerLookNode(null, treeData, function (node) {
            node.$$check = false;
        });
    };
    TreeViewService.prototype.appendNodes = function (treeData, valueField, parentId, nodes) {
        if (parentId) {
            var parentNode = this.getTreeNodeByValue(treeData, valueField, parentId);
            parentNode.node.children = parentNode.node.children || [];
            (_a = parentNode.node.children).push.apply(_a, nodes);
            return parentNode;
        }
        treeData.push.apply(treeData, nodes);
        var _a;
    };
    TreeViewService.prototype.removeNode = function (treeData, valueField, value) {
        var node = this.getTreeNodeByValue(treeData, valueField, value);
        if (node.parent) {
            node.parent.children = node.parent.children.filter(function (nodeItem) { return nodeItem[valueField] !== value; });
        }
        else {
            var index = treeData.indexOf(node.node);
            if (index !== -1) {
                treeData.splice(index, 1);
            }
        }
        return node;
    };
    TreeViewService.prototype.innerLookNode = function (parent, items, action) {
        var _this = this;
        if (!items) {
            return;
        }
        var nodes = [];
        items.forEach(function (nodeItem) {
            action(nodeItem, parent);
            _this.innerLookNode(nodeItem, nodeItem.children, action);
        });
        return nodes;
    };
    TreeViewService.prototype.innerGetMatchedItems = function (parent, items, match) {
        var _this = this;
        if (!items) {
            return [];
        }
        var nodes = [];
        items.forEach(function (nodeItem) {
            if (match(nodeItem)) {
                nodes.push({ node: nodeItem, parent: parent });
            }
            nodes.push.apply(nodes, _this.innerGetMatchedItems(nodeItem, nodeItem.children, match));
        });
        return nodes;
    };
    TreeViewService.prototype.innerGetFirstMatchedItem = function (parent, items, match) {
        if (!items) {
            return;
        }
        for (var i = 0; i < items.length; i++) {
            var nodeItem = items[i];
            if (match(nodeItem)) {
                return { node: nodeItem, parent: parent };
            }
            var matchNode = this.innerGetFirstMatchedItem(nodeItem, nodeItem.children, match);
            if (matchNode) {
                return matchNode;
            }
        }
    };
    return TreeViewService;
}());
export { TreeViewService };
TreeViewService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
TreeViewService.ctorParameters = function () { return []; };
//# sourceMappingURL=tree-view.service.js.map